==> date-fns-0.14.11.tgz: package/src/date_fns.js <==
var dateFns = {
  addDays: require('./add_days'),
  addHours: require('./add_hours'),
  addMinutes: require('./add_minutes'),
  addMonths: require('./add_months'),
  compareAsc: require('./compare_asc'),
  compareDesc: require('./compare_desc'),
  eachDay: require('./each_day'),
  endOfDay: require('./end_of_day'),
  endOfHour: require('./end_of_hour'),
  endOfMonth: require('./end_of_month'),
  endOfWeek: require('./end_of_week'),
  format: require('./format'),
  getISOWeek: require('./get_iso_week'),
  getISOYear: require('./get_iso_year'),
  isAfter: require('./is_after'),
  isBefore: require('./is_before'),
  isEqual: require('./is_equal'),
  isFirstDayOfMonth: require('./is_first_day_of_month'),
  isFuture: require('./is_future'),
  isLastDayOfMonth: require('./is_last_day_of_month'),
  isSameDay: require('./is_same_day'),
  isSameMonth: require('./is_same_month'),
  isSameWeek: require('./is_same_week'),
  isSameYear: require('./is_same_year'),
  isToday: require('./is_today'),
  isWeekend: require('./is_weekend'),
  isWithinRange: require('./is_within_range'),
  parse: require('./parse'),
  setISOWeek: require('./set_iso_week'),
  setISOYear: require('./set_iso_year'),
  setMonth: require('./set_month'),
  setYear: require('./set_year'),
  startOfDay: require('./start_of_day'),
  startOfHour: require('./start_of_hour'),
  startOfISOYear: require('./start_of_iso_year'),
  startOfMonth: require('./start_of_month'),
  startOfWeek: require('./start_of_week'),
  startOfYear: require('./start_of_year'),
  subDays: require('./sub_days'),
  subHours: require('./sub_hours'),
  subMinutes: require('./sub_minutes'),
  subMonths: require('./sub_months')
};

module.exports = dateFns;

==> date-fns-0.15.0.tgz: package/src/date_fns.js <==
var dateFns = {
  addDays: require('./add_days'),
  addHours: require('./add_hours'),
  addMilliseconds: require('./add_milliseconds'),
  addMinutes: require('./add_minutes'),
  addMonths: require('./add_months'),
  addSeconds: require('./add_seconds'),
  addYears: require('./add_years'),
  compareAsc: require('./compare_asc'),
  compareDesc: require('./compare_desc'),
  eachDay: require('./each_day'),
  endOfDay: require('./end_of_day'),
  endOfHour: require('./end_of_hour'),
  endOfMinute: require('./end_of_minute'),
  endOfMonth: require('./end_of_month'),
  endOfSecond: require('./end_of_second'),
  endOfWeek: require('./end_of_week'),
  endOfYear: require('./end_of_year'),
  format: require('./format'),
  getDayOfYear: require('./get_day_of_year'),
  getISOWeek: require('./get_iso_week'),
  getISOYear: require('./get_iso_year'),
  getQuarter: require('./get_quarter'),
  isAfter: require('./is_after'),
  isBefore: require('./is_before'),
  isEqual: require('./is_equal'),
  isFirstDayOfMonth: require('./is_first_day_of_month'),
  isFuture: require('./is_future'),
  isLastDayOfMonth: require('./is_last_day_of_month'),
  isPast: require('./is_past'),
  isSameDay: require('./is_same_day'),
  isSameMonth: require('./is_same_month'),
  isSameWeek: require('./is_same_week'),
  isSameYear: require('./is_same_year'),
  isToday: require('./is_today'),
  isWeekend: require('./is_weekend'),
  isWithinRange: require('./is_within_range'),
  lastDayOfMonth: require('./last_day_of_month'),
  lastDayOfYear: require('./last_day_of_year'),
  parse: require('./parse'),
  setDayOfYear: require('./set_day_of_year'),
  setISOWeek: require('./set_iso_week'),
  setISOYear: require('./set_iso_year'),
  setMonth: require('./set_month'),
  setQuarter: require('./set_quarter'),
  setYear: require('./set_year'),
  startOfDay: require('./start_of_day'),
  startOfHour: require('./start_of_hour'),
  startOfISOYear: require('./start_of_iso_year'),
  startOfMinute: require('./start_of_minute'),
  startOfMonth: require('./start_of_month'),
  startOfSeconds: require('./start_of_second'),
  startOfWeek: require('./start_of_week'),
  startOfYear: require('./start_of_year'),
  subDays: require('./sub_days'),
  subHours: require('./sub_hours'),
  subMilliseconds: require('./sub_milliseconds'),
  subMinutes: require('./sub_minutes'),
  subMonths: require('./sub_months'),
  subSeconds: require('./sub_seconds'),
  subYears: require('./sub_years')
}

module.exports = dateFns
